=========
RL-Agents
=========


.. image:: https://img.shields.io/pypi/v/rl-agents.svg
        :target: https://pypi.python.org/pypi/rl-agents

.. image:: https://img.shields.io/travis/mateuspontesm/rl-agents.svg
        :target: https://travis-ci.org/mateuspontesm/rl-agents

.. image:: https://readthedocs.org/projects/rl-agents/badge/?version=latest
        :target: https://rl-agents.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Implementation of various reinforcement learning methods.


* Free software: BSD 3-Clause 'New' or 'Revised' License

* Documentation: https://rl-agents.readthedocs.io.



Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `mateuspontesm/cookiecutter-poetry`_ project template,
a fork of `johanvergeer/cookiecutter-poetry`_ project template

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`johanvergeer/cookiecutter-poetry`: https://github.com/johanvergeer/cookiecutter-poetry
.. _`mateuspontesm/cookiecutter-poetry`: https://github.com/mateuspontesm/cookiecutter-poetry
